==> plantuml-libs-5.2.0.tgz: package/distribution/aws-20210730/Resource/ApplicationIntegration/AmazonEventBridgeRule.md <==
# AmazonEventBridgeRule


```text
aws-20210730/Resource/ApplicationIntegration/AmazonEventBridgeRule
```

```text
include('aws-20210730/Resource/ApplicationIntegration/AmazonEventBridgeRule')
```



| Illustration | AmazonEventBridgeRule | AmazonEventBridgeRuleCard | AmazonEventBridgeRuleGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/ApplicationIntegration/AmazonEventBridgeRule.png) | ![illustration for AmazonEventBridgeRule](../../../aws-20210730/Resource/ApplicationIntegration/AmazonEventBridgeRule.Local.png) | ![illustration for AmazonEventBridgeRuleCard](../../../aws-20210730/Resource/ApplicationIntegration/AmazonEventBridgeRuleCard.Local.png) | ![illustration for AmazonEventBridgeRuleGroup](../../../aws-20210730/Resource/ApplicationIntegration/AmazonEventBridgeRuleGroup.Local.png) |




## AmazonEventBridgeRule

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonEventBridgeRule
include('aws-20210730/Resource/ApplicationIntegration/AmazonEventBridgeRule')

' renders the element
AmazonEventBridgeRule('AmazonEventBridgeRule', 'Amazon Event Bridge Rule', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonEventBridgeRule
include('aws-20210730/Resource/ApplicationIntegration/AmazonEventBridgeRule')

' renders the element
AmazonEventBridgeRule('AmazonEventBridgeRule', 'Amazon Event Bridge Rule', 'an optional tech label')
@enduml
```

## AmazonEventBridgeRuleCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonEventBridgeRuleCard
include('aws-20210730/Resource/ApplicationIntegration/AmazonEventBridgeRule')

' renders the element
AmazonEventBridgeRuleCard('AmazonEventBridgeRuleCard', 'Amazon Event Bridge Rule Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonEventBridgeRuleCard
include('aws-20210730/Resource/ApplicationIntegration/AmazonEventBridgeRule')

' renders the element
AmazonEventBridgeRuleCard('AmazonEventBridgeRuleCard', 'Amazon Event Bridge Rule Card', 'an optional description')
@enduml
```

## AmazonEventBridgeRuleGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonEventBridgeRuleGroup
include('aws-20210730/Resource/ApplicationIntegration/AmazonEventBridgeRule')

' renders the element
AmazonEventBridgeRuleGroup('AmazonEventBridgeRuleGroup', 'Amazon Event Bridge Rule Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonEventBridgeRuleGroup
include('aws-20210730/Resource/ApplicationIntegration/AmazonEventBridgeRule')

' renders the element
AmazonEventBridgeRuleGroup('AmazonEventBridgeRuleGroup', 'Amazon Event Bridge Rule Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.4.0.tgz: package/distribution/aws-20210730/Resource/ApplicationIntegration/AmazonEventBridgeRule.md <==
# AmazonEventBridgeRule


```text
aws-20210730/Resource/ApplicationIntegration/AmazonEventBridgeRule
```

```text
include('aws-20210730/Resource/ApplicationIntegration/AmazonEventBridgeRule')
```



| Illustration | AmazonEventBridgeRule | AmazonEventBridgeRuleCard | AmazonEventBridgeRuleGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/ApplicationIntegration/AmazonEventBridgeRule.png) | ![illustration for AmazonEventBridgeRule](../../../aws-20210730/Resource/ApplicationIntegration/AmazonEventBridgeRule.Local.png) | ![illustration for AmazonEventBridgeRuleCard](../../../aws-20210730/Resource/ApplicationIntegration/AmazonEventBridgeRuleCard.Local.png) | ![illustration for AmazonEventBridgeRuleGroup](../../../aws-20210730/Resource/ApplicationIntegration/AmazonEventBridgeRuleGroup.Local.png) |




## AmazonEventBridgeRule

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonEventBridgeRule
include('aws-20210730/Resource/ApplicationIntegration/AmazonEventBridgeRule')

' renders the element
AmazonEventBridgeRule('AmazonEventBridgeRule', 'Amazon Event Bridge Rule', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonEventBridgeRule
include('aws-20210730/Resource/ApplicationIntegration/AmazonEventBridgeRule')

' renders the element
AmazonEventBridgeRule('AmazonEventBridgeRule', 'Amazon Event Bridge Rule', 'an optional tech label')
@enduml
```

## AmazonEventBridgeRuleCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonEventBridgeRuleCard
include('aws-20210730/Resource/ApplicationIntegration/AmazonEventBridgeRule')

' renders the element
AmazonEventBridgeRuleCard('AmazonEventBridgeRuleCard', 'Amazon Event Bridge Rule Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonEventBridgeRuleCard
include('aws-20210730/Resource/ApplicationIntegration/AmazonEventBridgeRule')

' renders the element
AmazonEventBridgeRuleCard('AmazonEventBridgeRuleCard', 'Amazon Event Bridge Rule Card', 'an optional description')
@enduml
```

## AmazonEventBridgeRuleGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonEventBridgeRuleGroup
include('aws-20210730/Resource/ApplicationIntegration/AmazonEventBridgeRule')

' renders the element
AmazonEventBridgeRuleGroup('AmazonEventBridgeRuleGroup', 'Amazon Event Bridge Rule Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonEventBridgeRuleGroup
include('aws-20210730/Resource/ApplicationIntegration/AmazonEventBridgeRule')

' renders the element
AmazonEventBridgeRuleGroup('AmazonEventBridgeRuleGroup', 'Amazon Event Bridge Rule Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
